@@ -40,6 +40,7 @@ __all__ = [
     'IMAGE_EXAMPLE_GRAY_LINES',
     'IMAGE_EXAMPLE_METAL',
     'IMAGE_EXAMPLE_PYGAME_MENU',
+    'IMAGE_EXAMPLE_PYTHON',
     'IMAGE_EXAMPLE_WALLPAPER',
     'IMAGE_EXAMPLES',
 
@@ -65,7 +66,8 @@ from pygame_menu._base import Base
 from pygame_menu.locals import POSITION_NORTHWEST, POSITION_NORTHEAST, POSITION_CENTER, \
     POSITION_WEST, POSITION_SOUTHWEST, POSITION_EAST, POSITION_SOUTHEAST, \
     POSITION_SOUTH, POSITION_NORTH
-from pygame_menu.utils import assert_vector, assert_position, assert_color
+from pygame_menu.utils import assert_vector, assert_position, assert_color, \
+    load_pygame_image_file
 
 from pygame_menu._types import Tuple2IntType, Union, Vector2NumberType, Callable, \
     Tuple, List, NumberType, Optional, Dict, Tuple4IntType, Literal, Tuple2NumberType, \
@@ -78,10 +80,11 @@ IMAGE_EXAMPLE_CARBON_FIBER = __images_path__.format('carbon_fiber.png')
 IMAGE_EXAMPLE_GRAY_LINES = __images_path__.format('gray_lines.png')
 IMAGE_EXAMPLE_METAL = __images_path__.format('metal.png')
 IMAGE_EXAMPLE_PYGAME_MENU = __images_path__.format('pygame_menu.png')
+IMAGE_EXAMPLE_PYTHON = __images_path__.format('python.svg')
 IMAGE_EXAMPLE_WALLPAPER = __images_path__.format('wallpaper.jpg')
 
 IMAGE_EXAMPLES = (IMAGE_EXAMPLE_CARBON_FIBER, IMAGE_EXAMPLE_GRAY_LINES,
-                  IMAGE_EXAMPLE_METAL, IMAGE_EXAMPLE_PYGAME_MENU,
+                  IMAGE_EXAMPLE_METAL, IMAGE_EXAMPLE_PYGAME_MENU, IMAGE_EXAMPLE_PYTHON,
                   IMAGE_EXAMPLE_WALLPAPER)
 
 # Drawing modes
@@ -97,10 +100,15 @@ _VALID_IMAGE_MODES = (IMAGE_MODE_CENTER, IMAGE_MODE_FILL, IMAGE_MODE_REPEAT_X,
 
 # Other constants
 _VALID_IMAGE_FORMATS = ['.jpg', '.png', '.gif', '.bmp', '.pcx', '.tga', '.tif',
-                        '.lbm', '.pbm', '.pgm', '.ppm', '.xpm', 'BytesIO', 'base64']
+                        '.lbm', '.pbm', '.pgm', '.ppm', '.xpm', '.svg', 'BytesIO',
+                        'base64']
 
 # Custom types
 ColorChannelType = Literal['r', 'g', 'b']
+ChannelType = Union[ColorChannelType,
+                    Tuple[ColorChannelType, ColorChannelType],
+                    Tuple[ColorChannelType, ColorChannelType, ColorChannelType],
+                    List[ColorChannelType]]
 
 
 class BaseImage(Base):
@@ -192,7 +200,7 @@ class BaseImage(Base):
 
         # Load the image and store as a surface
         if load_from_file:
-            self._surface = pygame.image.load(image_path)
+            self._surface = load_pygame_image_file(image_path)
             self._original_surface = self._surface.copy()
 
         # Other internals
@@ -428,7 +436,11 @@ class BaseImage(Base):
         """
         return self.get_width(), self.get_height()
 
-    def get_at(self, pos: Tuple2NumberType, ignore_alpha: bool = False) -> Union[Tuple3IntType, Tuple4IntType]:
+    def get_at(
+            self,
+            pos: Tuple2NumberType,
+            ignore_alpha: bool = False
+    ) -> Union[Tuple3IntType, Tuple4IntType]:
         """
         Get the color from a certain position in image on x-axis and y-axis (x, y).
 
@@ -531,8 +543,10 @@ class BaseImage(Base):
         self._original_surface = self._surface.copy()
         return self
 
-    def apply_image_function(self, image_function: Callable[[int, int, int, int], Tuple4IntType]
-                             ) -> 'BaseImage':
+    def apply_image_function(
+            self,
+            image_function: Callable[[int, int, int, int], Tuple4IntType]
+    ) -> 'BaseImage':
         """
         Apply a function to each pixel of the image. The function will receive the
         red, green, blue and alpha colors and must return the same values. The
@@ -579,11 +593,7 @@ class BaseImage(Base):
 
         return self.apply_image_function(image_function=bw)
 
-    def pick_channels(self, channels: Union[ColorChannelType,
-                                            Tuple[ColorChannelType, ColorChannelType],
-                                            Tuple[ColorChannelType, ColorChannelType, ColorChannelType],
-                                            List[ColorChannelType]]
-                      ) -> 'BaseImage':
+    def pick_channels(self, channels: ChannelType) -> 'BaseImage':
         """
         Pick certain channels of the image, channels are ``"r"`` (red), ``"g"``
         (green) and ``"b"`` (blue), ``channels param`` is a list/tuple of channels
@@ -629,12 +639,23 @@ class BaseImage(Base):
         self._surface = pygame.transform.flip(self._surface, x, y)
         return self
 
-    def scale(self, width: NumberType, height: NumberType, smooth: bool = True) -> 'BaseImage':
+    def scale(
+            self,
+            width: NumberType,
+            height: NumberType,
+            smooth: bool = True
+    ) -> 'BaseImage':
         """
         Scale the image to a desired width and height factor.
 
-        :param width: Scale factor of the width
-        :param height: Scale factor of the height
+        .. note::
+
+            The scale transformation is permanent, and is applied over the same
+            object. Thus, if ``image.scale(2, 2).scale(2, 2)`` the final scale of
+            the initial image is equal to ``image.scale(4, 4)``.
+
+        :param width: Width scale factor
+        :param height: Height scale factor
         :param smooth: Smooth scaling
         :return: Self reference
         """
@@ -667,9 +688,22 @@ class BaseImage(Base):
         self._surface = pygame.transform.scale2x(self._surface)
         return self
 
-    def resize(self, width: NumberType, height: NumberType, smooth: bool = True) -> 'BaseImage':
+    def scale4x(self) -> 'BaseImage':
         """
-        Set the image size to another size.
+        Applies a x4 scale factor using scale2x algorithm.
+
+        :return: Self reference
+        """
+        return self.scale2x().scale2x()
+
+    def resize(
+            self,
+            width: NumberType,
+            height: NumberType,
+            smooth: bool = True
+    ) -> 'BaseImage':
+        """
+        Resize the image to a desired (width, height) size in pixels.
 
         :param width: New width of the image in px
         :param height: New height of the image in px
@@ -679,7 +713,8 @@ class BaseImage(Base):
         assert isinstance(width, NumberInstance)
         assert isinstance(height, NumberInstance)
         assert isinstance(smooth, bool)
-        assert width > 0 and height > 0, 'width and height must be greater than zero'
+        assert width > 0 and height > 0, \
+            'width and height must be greater than zero'
         w, h = self.get_size()
         if w == width and h == height:
             return self
@@ -774,8 +809,12 @@ class BaseImage(Base):
         else:
             raise ValueError('unknown drawing position')
 
-    def draw(self, surface: 'pygame.Surface', area: Optional['pygame.Rect'] = None,
-             position: Tuple2IntType = (0, 0)) -> 'BaseImage':
+    def draw(
+            self,
+            surface: 'pygame.Surface',
+            area: Optional['pygame.Rect'] = None,
+            position: Tuple2IntType = (0, 0)
+    ) -> 'BaseImage':
         """
         Draw the image in a given surface.
 
