@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 EXAMPLE - MULTI-INPUT
 Shows different inputs (widgets).
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,10 +29,13 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
-import os
+__all__ = ['main']
 
 import pygame
 import pygame_menu
+from pygame_menu.examples import create_example_window
+
+from typing import Tuple, Optional
 
 # -----------------------------------------------------------------------------
 # Constants and global variables
@@ -44,18 +43,15 @@ import pygame_menu
 FPS = 60
 WINDOW_SIZE = (640, 480)
 
-# noinspection PyTypeChecker
-sound = None  # type: pygame_menu.sound.Sound
-# noinspection PyTypeChecker
-surface = None  # type: pygame.Surface
-# noinspection PyTypeChecker
-main_menu = None  # type: pygame_menu.Menu
+sound: Optional['pygame_menu.sound.Sound'] = None
+surface: Optional['pygame.Surface'] = None
+main_menu: Optional['pygame_menu.Menu'] = None
 
 
 # -----------------------------------------------------------------------------
 # Methods
 # -----------------------------------------------------------------------------
-def main_background():
+def main_background() -> None:
     """
     Background color of the main menu, on this function user can plot
     images, play sounds, etc.
@@ -65,28 +61,25 @@ def main_background():
     surface.fill((40, 40, 40))
 
 
-def check_name_test(value):
+def check_name_test(value: str) -> None:
     """
     This function tests the text input widget.
 
     :param value: The widget value
-    :type value: str
     :return: None
     """
     print('User name: {0}'.format(value))
 
 
-# noinspection PyUnusedLocal
-def update_menu_sound(value, enabled):
+def update_menu_sound(value: Tuple, enabled: bool) -> None:
     """
     Update menu sound.
 
     :param value: Value of the selector (Label and index)
-    :type value: tuple
     :param enabled: Parameter of the selector, (True/False)
-    :type enabled: bool
     :return: None
     """
+    assert isinstance(value, tuple)
     if enabled:
         main_menu.set_sound(sound, recursive=True)
         print('Menu sounds were enabled')
@@ -95,12 +88,11 @@ def update_menu_sound(value, enabled):
         print('Menu sounds were disabled')
 
 
-def main(test=False):
+def main(test: bool = False) -> None:
     """
     Main program.
 
     :param test: Indicate function is being tested
-    :type test: bool
     :return: None
     """
 
@@ -112,14 +104,9 @@ def main(test=False):
     global surface
 
     # -------------------------------------------------------------------------
-    # Init pygame
+    # Create window
     # -------------------------------------------------------------------------
-    pygame.init()
-    os.environ['SDL_VIDEO_CENTERED'] = '1'
-
-    # Create pygame screen and objects
-    surface = pygame.display.set_mode(WINDOW_SIZE)
-    pygame.display.set_caption('Example - Multi Input')
+    surface = create_example_window('Example - Multi Input', WINDOW_SIZE)
     clock = pygame.time.Clock()
 
     # -------------------------------------------------------------------------
@@ -144,27 +131,26 @@ def main(test=False):
 
     settings_menu = pygame_menu.Menu(
         height=WINDOW_SIZE[1] * 0.85,
-        onclose=pygame_menu.events.DISABLE_CLOSE,
         theme=settings_menu_theme,
         title='Settings',
         width=WINDOW_SIZE[0] * 0.9
     )
 
     # Add text inputs with different configurations
-    wid1 = settings_menu.add_text_input(
+    settings_menu.add.text_input(
         'First name: ',
         default='John',
         onreturn=check_name_test,
         textinput_id='first_name'
     )
-    wid2 = settings_menu.add_text_input(
+    settings_menu.add.text_input(
         'Last name: ',
         default='Rambo',
         maxchar=10,
         textinput_id='last_name',
         input_underline='.'
     )
-    settings_menu.add_text_input(
+    settings_menu.add.text_input(
         'Your age: ',
         default=25,
         maxchar=3,
@@ -173,13 +159,13 @@ def main(test=False):
         input_type=pygame_menu.locals.INPUT_INT,
         cursor_selection_enable=False
     )
-    settings_menu.add_text_input(
+    settings_menu.add.text_input(
         'Some long text: ',
         maxwidth=19,
         textinput_id='long_text',
         input_underline='_'
     )
-    settings_menu.add_text_input(
+    settings_menu.add.text_input(
         'Password: ',
         maxchar=6,
         password=True,
@@ -187,17 +173,55 @@ def main(test=False):
         input_underline='_'
     )
 
+    # Selectable items
+    items = [('Easy', 'EASY'),
+             ('Medium', 'MEDIUM'),
+             ('Hard', 'HARD')]
+
     # Create selector with 3 difficulty options
-    settings_menu.add_selector(
-        'Select difficulty ',
-        [('Easy', 'EASY'),
-         ('Medium', 'MEDIUM'),
-         ('Hard', 'HARD')],
+    settings_menu.add.selector(
+        'Select difficulty:\t',
+        items,
         selector_id='difficulty',
         default=1
     )
+    settings_menu.add.selector(
+        'Select difficulty fancy',
+        items,
+        selector_id='difficulty_fancy',
+        default=1,
+        style='fancy'
+    )
+    settings_menu.add.dropselect(
+        'Select difficulty (drop)',
+        items,
+        default=1,
+        dropselect_id='difficulty_drop'
+    )
+    settings_menu.add.dropselect_multiple(
+        title='Pick 3 colors',
+        items=[('Black', (0, 0, 0)),
+               ('Blue', (0, 0, 255)),
+               ('Cyan', (0, 255, 255)),
+               ('Fuchsia', (255, 0, 255)),
+               ('Green', (0, 255, 0)),
+               ('Red', (255, 0, 0)),
+               ('White', (255, 255, 255)),
+               ('Yellow', (255, 255, 0))],
+        dropselect_multiple_id='pickcolors',
+        max_selected=3,
+        open_middle=True,
+        selection_box_height=6  # How many options show if opened
+    )
 
-    def data_fun():
+    # Create switch
+    settings_menu.add.toggle_switch('First Switch', False,
+                                    toggleswitch_id='first_switch')
+    settings_menu.add.toggle_switch('Other Switch', True,
+                                    toggleswitch_id='second_switch',
+                                    state_text=('Apagado', 'Encencido'))
+
+    def data_fun() -> None:
         """
         Print data of the menu.
 
@@ -208,8 +232,10 @@ def main(test=False):
         for k in data.keys():
             print(u'\t{0}\t=>\t{1}'.format(k, data[k]))
 
-    settings_menu.add_button('Store data', data_fun)  # Call function
-    settings_menu.add_button('Return to main menu', pygame_menu.events.BACK,
+    settings_menu.add.clock(clock_format='%Y/%m/%d %H:%M', title_format='Clock: {0}')
+    settings_menu.add.button('Store data', data_fun)  # Call function
+    settings_menu.add.button('Restore original values', settings_menu.reset_value)
+    settings_menu.add.button('Return to main menu', pygame_menu.events.BACK,
                              align=pygame_menu.locals.ALIGN_CENTER)
 
     # -------------------------------------------------------------------------
@@ -217,46 +243,45 @@ def main(test=False):
     # -------------------------------------------------------------------------
     more_settings_menu = pygame_menu.Menu(
         height=WINDOW_SIZE[1] * 0.85,
-        onclose=pygame_menu.events.DISABLE_CLOSE,
         theme=settings_menu_theme,
         title='More Settings',
         width=WINDOW_SIZE[0] * 0.9
     )
 
-    more_settings_menu.add_image(
+    more_settings_menu.add.image(
         pygame_menu.baseimage.IMAGE_EXAMPLE_PYGAME_MENU,
         scale=(0.25, 0.25),
         align=pygame_menu.locals.ALIGN_CENTER
     )
-    more_settings_menu.add_color_input(
+    more_settings_menu.add.color_input(
         'Color 1 RGB: ',
         color_type='rgb'
     )
-    more_settings_menu.add_color_input(
+    more_settings_menu.add.color_input(
         'Color 2 RGB: ',
         color_type='rgb',
         default=(255, 0, 0),
         input_separator='-'
     )
 
-    def print_color(color):
+    def print_color(color: Tuple) -> None:
         """
         Test onchange/onreturn.
 
         :param color: Color tuple
-        :type color: tuple
         :return: None
         """
         print('Returned color: ', color)
 
-    more_settings_menu.add_color_input(
+    more_settings_menu.add.color_input(
         'Color in Hex: ',
         color_type='hex',
+        hex_format='lower',
         onreturn=print_color
     )
 
-    more_settings_menu.add_vertical_margin(25)
-    more_settings_menu.add_button(
+    more_settings_menu.add.vertical_margin(25)
+    more_settings_menu.add.button(
         'Return to main menu',
         pygame_menu.events.BACK,
         align=pygame_menu.locals.ALIGN_CENTER
@@ -266,7 +291,7 @@ def main(test=False):
     # Create menus: Column buttons
     # -------------------------------------------------------------------------
     button_column_menu_theme = pygame_menu.themes.THEME_ORANGE.copy()
-    button_column_menu_theme.background_color = pygame_menu.baseimage.BaseImage(
+    button_column_menu_theme.background_color = pygame_menu.BaseImage(
         image_path=pygame_menu.baseimage.IMAGE_EXAMPLE_GRAY_LINES,
         drawing_mode=pygame_menu.baseimage.IMAGE_MODE_REPEAT_XY
     )
@@ -275,20 +300,19 @@ def main(test=False):
     button_column_menu = pygame_menu.Menu(
         columns=2,
         height=WINDOW_SIZE[1] * 0.45,
-        onclose=pygame_menu.events.DISABLE_CLOSE,
         rows=3,
         theme=button_column_menu_theme,
         title='Textures+Columns',
         width=WINDOW_SIZE[0] * 0.9
     )
     for i in range(4):
-        button_column_menu.add_button('Button {0}'.format(i), pygame_menu.events.BACK)
-    button_column_menu.add_button(
+        button_column_menu.add.button('Button {0}'.format(i), pygame_menu.events.BACK)
+    button_column_menu.add.button(
         'Return to main menu', pygame_menu.events.BACK,
-        background_color=pygame_menu.baseimage.BaseImage(
+        background_color=pygame_menu.BaseImage(
             image_path=pygame_menu.baseimage.IMAGE_EXAMPLE_METAL
         )
-    )
+    ).background_inflate_to_selection_effect()
 
     # -------------------------------------------------------------------------
     # Create menus: Main menu
@@ -306,17 +330,13 @@ def main(test=False):
         width=WINDOW_SIZE[0] * 0.8
     )
 
-    main_menu.add_button('Settings', settings_menu, padding=(0, 0, 0, 0))
-    main_menu.add_button('More Settings', more_settings_menu)
-    main_menu.add_button('Menu in textures and columns', button_column_menu)
-    main_menu.add_selector('Menu sounds ',
+    main_menu.add.button('Settings', settings_menu)
+    main_menu.add.button('More Settings', more_settings_menu)
+    main_menu.add.button('Menu in textures and columns', button_column_menu)
+    main_menu.add.selector('Menu sounds ',
                            [('Off', False), ('On', True)],
                            onchange=update_menu_sound)
-    main_menu.add_button('Quit', pygame_menu.events.EXIT)
-
-    assert main_menu.get_widget('first_name', recursive=True) is wid1
-    assert main_menu.get_widget('last_name', recursive=True) is wid2
-    assert main_menu.get_widget('last_name') is None
+    main_menu.add.button('Quit', pygame_menu.events.EXIT)
 
     # -------------------------------------------------------------------------
     # Main loop
