@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 pygame-menu
 https://github.com/ppizarror/pygame-menu
@@ -6,9 +5,6 @@ https://github.com/ppizarror/pygame-menu
 VERTICAL MARGIN
 Vertical box margin.
 
-NOTE: pygame-menu v3 will not provide new widgets or functionalities, consider
-upgrading to the latest version.
-
 License:
 -------------------------------------------------------------------------------
 The MIT License (MIT)
@@ -33,48 +29,36 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 -------------------------------------------------------------------------------
 """
 
-from pygame_menu.utils import make_surface
-from pygame_menu.widgets.core import Widget
+__all__ = ['VMargin']
+
+import pygame
+
+from pygame_menu.widgets.widget.none import NoneWidget
+
+from pygame_menu._types import NumberType
 
 
 # noinspection PyMissingOrEmptyDocstring
-class VMargin(Widget):
+class VMargin(NoneWidget):
     """
-    Vertical margin widget.
+    Vertical margin widget. VMargin only accepts margin, not padding.
 
     .. note::
 
         This widget does not implement any transformation.
 
+    :param margin: Vertical margin in px
     :param widget_id: ID of the widget
-    :type widget_id: str
     """
 
-    def __init__(self, widget_id=''):
+    def __init__(
+            self,
+            margin: NumberType,
+            widget_id: str = ''
+    ) -> None:
         super(VMargin, self).__init__(widget_id=widget_id)
-        self.is_selectable = False
+        self._rect.width = 0
+        self._rect.height = int(margin)
 
-    def _apply_font(self):
-        self._font_size = 0
-        self._shadow = False
-
-    def set_padding(self, padding):  # Don't accept padding
-        pass
-
-    # noinspection PyMissingOrEmptyDocstring
-    def draw(self, surface):
-        self._render()
-        surface.blit(self._surface, self._rect.topleft)
-
-    def _render(self):
-        if self._surface is not None:
-            return True
-        self._surface = make_surface(1, 1, alpha=True)
-        self._rect.width = 0.0
-        self._rect.height = 0.0
-        if not self._render_hash_changed(self.visible):
-            return True
-
-    # noinspection PyMissingOrEmptyDocstring
-    def update(self, events):
-        return False
+    def get_rect(self, *args, **kwargs) -> 'pygame.Rect':
+        return self._rect.copy()
